@@ -53,7 +53,8 @@ class Optimizer:
                                                   class_type='algorithm')
 
         self.opt_alg_obj = self.optimizer_attribute(optimization_dict=optimization_dict,
-                                                    communication_obj=self.communication_obj)
+                                                    communication_obj=self.communication_obj,
+                                                    FoM_object=FoM_object)
 
     def execute(self):
         """ Write this docstring """
