@@ -32,7 +32,7 @@ class AlgorithmTemplate(OptimizationAlgorithm):
     * _get_final_results: return the final result of the optimization algorithm
     """
 
-    def __init__(self, optimization_dict: dict = None, communication_obj=None):
+    def __init__(self, optimization_dict: dict = None, communication_obj=None, **kwargs):
         """
         This is the implementation of the dCRAB algorithm. All the arguments in the constructor are passed to the
         OptimizationAlgorithm class except the optimization dictionary where the dCRAB settings and the controls are defined.
