@@ -33,8 +33,7 @@ class AbstractDump(metaclass=ABCMeta):
                       pulses_list: list = [],
                       time_grids_list: list = [],
                       parameters_list: list = [],
-                      **kwargs
-                      ) -> None:
+                      **kwargs) -> None:
         """
         Abstract method for dumping the controls.
         :param list pulses_list: List of np.array. Every np.array is a pulse.
